@@ -1,6 +1,6 @@
 package Bundle::Personal::lze;
 
-$VERSION = '0.04';
+$VERSION = '0.10';
 
 1;
 
@@ -8,7 +8,7 @@ __END__
 
 =head1 NAME
 
-Bundle::Personal::lze - Personal bundle include all Modules i used.
+Bundle::Personal::lze - Personal bundle, include all Modules i used.
 
 =head1 SYNOPSIS
 
@@ -21,12 +21,6 @@ Apache::DB
 
 Apache2::Status
 
-Authen::Captcha
-
-CGI
-
-CGI::QuickForm
-
 Complete::Bash
 
 Complete::Util
@@ -41,12 +35,8 @@ DBI
 
 Frontier::RPC2
 
-GD
-
 Getopt::Long
 
-HTML::Menu::TreeView
-
 HTML::Parser
 
 IO::Prompter
@@ -55,20 +45,10 @@ LWP::UserAgent
 
 MD5
 
-Mail::Sendmail
-
 Module::Build
 
-MySQL::Admin
-
 Pod::Usage
 
-Search::Tools::UTF8
-
-Syntax::Highlight::Engine::Kate
-
-Syntax::Highlight::Perl
-
 Term::ANSIColor
 
 Term::Bash::Completion::Generator
